summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/deco_zoomspr.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/deco_zoomspr.cpp')
-rw-r--r--src/mame/video/deco_zoomspr.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/deco_zoomspr.cpp b/src/mame/video/deco_zoomspr.cpp
index 4a613bf5e78..c8266df83e6 100644
--- a/src/mame/video/deco_zoomspr.cpp
+++ b/src/mame/video/deco_zoomspr.cpp
@@ -22,13 +22,13 @@ deco_zoomspr_device::deco_zoomspr_device(const machine_config &mconfig, const ch
}
//-------------------------------------------------
// static_set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------
-void deco_zoomspr_device::static_set_gfxdecode_tag(device_t &device, const char *tag)
+void deco_zoomspr_device::set_gfxdecode_tag(const char *tag)
{
- downcast<deco_zoomspr_device &>(device).m_gfxdecode.set_tag(tag);
+ m_gfxdecode.set_tag(tag);
}
@@ -22,13 +22,13 @@ deco_zoomspr_device::deco_zoomspr_device(const machine_config &mconfig, const ch
}
//-------------------------------------------------
-// static_set_gfxdecode_tag: Set the tag of the
+// set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------